@@ -10,17 +10,25 @@ from hexss.modbus.serial.robot import Robot
 def main():
     comport = get_comport(
         'ATEN USB to Serial',
-        'IAI USB to UART Bridge Controller',
         'USB-Serial Controller',
-        'USB Serial Port'
+        'Prolific PL2303GC USB Serial COM Port',
+        # 'IAI USB to UART Bridge Controller',
+        # 'USB Serial Port'
     )
     print(f"Using COM port: {comport}\n")
-    robot = Robot(comport=comport, baudrate=38400, num_slaves=4)
     config = load_config('control_robot_server', {
-        'ipv4': '0.0.0.0',
-        'port': 2005,
-        'num_slaves': robot.num_slaves
+        "ipv4": '0.0.0.0',
+        "port": 2005,
+        "slaves": {
+            0: {
+                "min_max_position": [
+                    0,
+                    40000
+                ]
+            }
+        }
     })
+    robot = Robot(comport=comport, baudrate=38400, slaves=config['slaves'])
     close_port(config['ipv4'], config['port'])
 
     data = {
