@@ -1,14 +1,14 @@
+import inspect
 import os
 import re
 import subprocess
 import sys
 import platform
 import ctypes
+import types
 from pathlib import Path
 from typing import Optional, Union
 
-import hexss
-
 
 def get_venv_dir() -> Optional[Path]:
     """
@@ -80,7 +80,7 @@ def get_python_path() -> Path:
     return Path(sys.executable)
 
 
-def get_script_dir() -> Path:
+def get_script_dir(strict=False) -> Path | None:
     """
     Returns the directory where the current script is located.
 
@@ -91,10 +91,48 @@ def get_script_dir() -> Path:
         # Resolve the absolute path of the script and return its parent directory.
         return Path(sys.argv[0]).resolve().parent
     except Exception as e:
-        raise RuntimeError("Unable to determine the script directory.") from e
+        if strict:
+            raise RuntimeError("Unable to determine the script directory.") from e
 
 
-def get_current_working_dir() -> Path:
+def get_direct_caller():
+    # Path of the direct caller (importer)
+    frame = inspect.currentframe()
+    caller_frame = frame.f_back
+    caller_file = Path(caller_frame.f_code.co_filename).resolve()
+    return caller_file
+
+
+def get_source_file(obj, strict=False) -> Path | None:
+    """Return absolute path of the file where `obj` is defined."""
+    # Module
+    if isinstance(obj, types.ModuleType):
+        f = getattr(obj, "__file__", None)
+        if f is None:
+            if strict:
+                raise ValueError("Module has no file (built-in or namespace package).")
+        return Path(f).resolve()
+
+    # Function / method
+    if inspect.isfunction(obj) or inspect.ismethod(obj):
+        return Path(obj.__code__.co_filename).resolve()
+
+    # Class
+    if inspect.isclass(obj):
+        return Path(inspect.getfile(obj)).resolve()
+
+    # Fallback: use the object's module if available
+    mod = inspect.getmodule(obj)
+    if mod and getattr(mod, "__file__", None):
+        return Path(mod.__file__).resolve()
+
+    if strict:
+        raise TypeError(f"Unsupported object type: {type(obj)!r}")
+
+    return None
+
+
+def get_current_working_dir(strict=False) -> Path:
     """
     Returns the current working directory.
 
@@ -104,7 +142,8 @@ def get_current_working_dir() -> Path:
     try:
         return Path.cwd()
     except Exception as e:
-        raise RuntimeError("Unable to retrieve the current working directory.") from e
+        if strict:
+            raise RuntimeError("Unable to retrieve the current working directory.") from e
 
 
 def ascend_path(path: Path, levels: int = 1) -> Path:
@@ -354,4 +393,3 @@ if __name__ == "__main__":
                     print("    -> [Permission Denied]")
                 except OSError as e:
                     print(f"    -> [Error: {e}]")
-
